ethz_snow — ethz_snow 1.0.0 documentation

# ethz_snow

This is the documentation of ethz_snow. A package for the simulation of stochastic nucleation of water in small vials. Please have a look at the Overview for a high-level description of what this package does, or check out the Tutorial.

## Getting Started

This package can be installed via pip. Simply use

    pip install ethz_snow

or see the Tutorial for more details.

## Contents

- Overview
- ethz_snow
  - Description
  - Bug reports
- Tutorial
- Installation
- First steps: General information
  - Constants
- Example
- Simulation output
- License
- Authors
- Changelog
  - Version 1.0
- Module Reference
  - ethz_snow package

## Indices and Tables

- Index

- Module Index

- Search Page